@@ -10,7 +10,7 @@ would appreciate credit if this program or parts of it are used.
 
 #include <stdio.h>
 
-#include "Dbg_cf.h"
+#include "tcldbgcf.h"
 #if 0
 /* tclInt.h drags in stdlib.  By claiming no-stdlib, force it to drag in */
 /* Tcl's compat version.  This avoids having to test for its presence */
@@ -27,7 +27,7 @@ would appreciate credit if this program or parts of it are used.
 /*				objects to including varargs.h twice, just */
 /*				omit this one. */
 /*#include "string.h"		tclInt.h drags this in, too! */
-#include "Dbg.h"
+#include "tcldbg.h"
 
 #ifndef TRUE
 #define TRUE 1
@@ -74,7 +74,7 @@ static int goalNumLevel;	/* destination for Next */
 
 static enum debug_cmd {
 	none, step, next, ret, cont, up, down, where, Next
-} debug_cmd;
+} debug_cmd = step;
 
 /* info about last action to use as a default */
 static enum debug_cmd last_action_cmd = next;
@@ -434,7 +434,7 @@ Tcl_Obj *objv[];
 	argv[argc] = Tcl_GetStringFromObj(objv[argc],&len);
     }
     argv[argc] = NULL;
-    print_argv(interp,argc,argv);
+    return(print_argv(interp,argc,argv));
 }
 #endif
 
@@ -507,6 +507,23 @@ Interp *iptr;
 	return 0;
 }
 
+static char *cmd_print(cmdtype)
+enum debug_cmd cmdtype;
+{
+	switch (cmdtype) {
+	case none:  return "cmd: none";
+	case step:  return "cmd: step";
+	case next:  return "cmd: next";
+	case ret:   return "cmd: ret";
+	case cont:  return "cmd: cont";
+	case up:    return "cmd: up";
+	case down:  return "cmd: down";
+	case where: return "cmd: where";
+	case Next:  return "cmd: Next";
+	}
+	return "cmd: Unknown";
+}
+
 /* debugger's trace handler */
 /*ARGSUSED*/
 static void
@@ -571,11 +588,13 @@ char *argv[];
 		break_status |= breakpoint_test(interp,command,b);
 	}
 	if (break_status) {
-		if (!debug_new_action) goto start_interact;
+		if (!debug_new_action) {
+			goto start_interact;
+		}
 
 		/* if s or n triggered by breakpoint, make "s 1" */
 		/* (and so on) refer to next command, not this one */
-/*		step_count++;*/
+		/* step_count++;*/
 		goto end_interact;
 	}
 
@@ -686,6 +705,7 @@ char **argv;
 {
 	debug_new_action = TRUE;
 	debug_cmd = *(enum debug_cmd *)clientData;
+
 	last_action_cmd = debug_cmd;
 
 	step_count = (argc == 1)?1:atoi(argv[1]);
@@ -1261,7 +1281,11 @@ int immediate;		/* if true, stop immediately */
 {
 	if (!debugger_active) init_debugger(interp);
 
-	debug_cmd = step;
+	/* intuitively, it would seem natural to initialize the
+	debugger with the step command.  However, it's too late at
+	this point.  It must be done before the command reader
+	(whatever it is) has gotten control. */
+	/* debug_cmd = step;*/
 	step_count = 1;
 
 	if (immediate) {
@@ -1288,4 +1312,8 @@ Tcl_Interp *interp;
 	Tcl_DeleteTrace(interp,debug_handle);
 	debugger_active = FALSE;
 	Tcl_UnsetVar(interp,Dbg_VarName,TCL_GLOBAL_ONLY);
+
+	/* initialize for next use */
+	debug_cmd = step;
+	step_count = 1;
 }
