@@ -3,8 +3,25 @@
 #include "expect_cf.h"
 #include <stdio.h>
 #include <signal.h>
+#include "string.h"
+
+#ifdef HAVE_SYS_FCNTL_H
+#  include <sys/fcntl.h>
+#else
+#  include <fcntl.h>
+#endif
+
+#include <sys/stat.h>
+
+#ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+#endif
 #include <sys/types.h>
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
 #ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
@@ -438,8 +455,8 @@ char **argv;
 
 			/* find out what weird options user asked for */
 			if (exp_tty_get_simple(&tty_current) == -1) {
-				errorlog("ioctl(get): %s\r\n",Tcl_PosixError(interp));
-				exp_exit(interp,1);
+				exp_error(interp,"stty: ioctl(get): %s\r\n",Tcl_PosixError(interp));
+				rc = TCL_ERROR;
 			}
 			if (cooked) {
 				/* find out user's new defn of 'cooked' */
@@ -735,8 +752,8 @@ char **argv;
 
 static struct exp_cmd_data
 cmd_data[]  = {
-{"stty",	Exp_SttyCmd,	0,	0},
-{"system",	Exp_SystemCmd,	0,	0},
+{"stty",	exp_proc(Exp_SttyCmd),	0,	0},
+{"system",	exp_proc(Exp_SystemCmd),	0,	0},
 {0}};
 
 void
